@@ -128,6 +128,9 @@ FAILEDOPERATION_ISDEFAULTMAPPING = 'FailedOperation.IsDefaultMapping'
 # 默认的二级域名输入错误。
 FAILEDOPERATION_NETSUBDOMAINERROR = 'FailedOperation.NetSubDomainError'
 
+# 操作后端通道失败。
+FAILEDOPERATION_OPERATEUPSTREAM = 'FailedOperation.OperateUpstream'
+
 # 设置路径映射错误。
 FAILEDOPERATION_PATHMAPPINGSETERROR = 'FailedOperation.PathMappingSetError'
 
@@ -182,6 +185,12 @@ INTERNALERROR_VPCEXCEPTION = 'InternalError.VpcException'
 # 参数错误。
 INVALIDPARAMETER = 'InvalidParameter'
 
+# 基础版服务不能绑定插件。
+INVALIDPARAMETER_BASICSERVICENOTALLOWATTACHPLUGIN = 'InvalidParameter.BasicServiceNotAllowAttachPlugin'
+
+# 当前绑定插件和已有插件冲突。
+INVALIDPARAMETER_DUPLICATEPLUGINCONFIG = 'InvalidParameter.DuplicatePluginConfig'
+
 # 参数格式错误。
 INVALIDPARAMETER_FORMATERROR = 'InvalidParameter.FormatError'
 
@@ -287,6 +296,9 @@ INVALIDPARAMETERVALUE_INVALIDUPSTREAM = 'InvalidParameterValue.InvalidUpstream'
 # URL参数错误。
 INVALIDPARAMETERVALUE_INVALIDURL = 'InvalidParameterValue.InvalidUrl'
 
+# 无效vpc信息。
+INVALIDPARAMETERVALUE_INVALIDVPCCONFIG = 'InvalidParameterValue.InvalidVpcConfig'
+
 # 方法错误。WEBSOCKET类型的后端服务，前端方法需要配置为GET。
 INVALIDPARAMETERVALUE_INVALIDWSMETHOD = 'InvalidParameterValue.InvalidWSMethod'
 
@@ -317,6 +329,9 @@ LIMITEXCEEDED = 'LimitExceeded'
 # API文档数量超出限制。
 LIMITEXCEEDED_APIDOCLIMITEXCEEDED = 'LimitExceeded.APIDocLimitExceeded'
 
+# 访问密钥数量超出限制。
+LIMITEXCEEDED_ACCESSKEYCOUNTINUSAGEPLANLIMITEXCEEDED = 'LimitExceeded.AccessKeyCountInUsagePlanLimitExceeded'
+
 # 服务绑定的应用数量超过限制。
 LIMITEXCEEDED_APIAPPCOUNTLIMITEXCEEDED = 'LimitExceeded.ApiAppCountLimitExceeded'
 
@@ -425,6 +440,9 @@ UNSUPPORTEDOPERATION_ALREADYBINDUSAGEPLAN = 'UnsupportedOperation.AlreadyBindUsa
 # 当前插件不支持绑定。
 UNSUPPORTEDOPERATION_ATTACHPLUGIN = 'UnsupportedOperation.AttachPlugin'
 
+# 基础版服务不能创建超过一个API。
+UNSUPPORTEDOPERATION_BASICSERVICENOMOREAPI = 'UnsupportedOperation.BasicServiceNoMoreApi'
+
 # 日志检索起始时间间隔。
 UNSUPPORTEDOPERATION_CLSSEARCHTIME = 'UnsupportedOperation.ClsSearchTime'
 
@@ -485,6 +503,9 @@ UNSUPPORTEDOPERATION_UNSUPPORTEDDELETEAPI = 'UnsupportedOperation.UnsupportedDel
 # 服务使用中，不能被删除。
 UNSUPPORTEDOPERATION_UNSUPPORTEDDELETESERVICE = 'UnsupportedOperation.UnsupportedDeleteService'
 
+# 当前VPC通道存在绑定关系，不支持当前操作。
+UNSUPPORTEDOPERATION_UNSUPPORTEDDELETEUPSTREAM = 'UnsupportedOperation.UnsupportedDeleteUpstream'
+
 # 不支持网络类型。
 UNSUPPORTEDOPERATION_UNSUPPORTEDNETTYPE = 'UnsupportedOperation.UnsupportedNetType'
 
